.. _utilipy-utils-metaclasses:

*****************************************
metaclasses (`utilipy.utils.metaclasses`)
*****************************************

.. currentmodule:: utilipy.utils.metaclasses


Reference/API
=============

.. automodapi:: utilipy.utils.metaclasses
